@@ -9,8 +9,9 @@ sub new {
 }
 
 ### (partial) fitness function, sum of differ between antigens and antibodies
-sub fitness_M0 ($antigen_genome, $antibody_genome, @args)
+sub fitness_M0 ($antibody_genome, @args)
 	my $sum = 0;
+	my $antigen_genome = @args[0];
 
 	for (my $i = 0; $i < scalar $antigen_genome->{genes}; $i++) {
 		if ($antigen_genome->{genes}[$i] == $antibody_genome->{genes}[$i]) {
